@@ -25,13 +25,17 @@ Help on package amuse.ic in amuse:
 or (directly from the terminal):
 > pydoc amuse.ic
 """
+import sys
+import os
 import numpy
 
+_AMUSE_ROOT = os.path.abspath(os.path.dirname(__file__))
+
 def numpy_fix():
     try:
-      numpy.set_printoptions(legacy='1.13')
+        numpy.set_printoptions(legacy='1.13')
     except TypeError:
-      pass
+        pass
       
 numpy_fix()
 
@@ -46,4 +50,15 @@ try:
 except Exception as ex:
     message="Configuration not read in - or configuration invalid, exception:\n"+str(ex)
     config=NoConfig(message)
-    
+
+
+
+# always report AMUSE reference information
+try:
+    from amuse.support.literature import TrackLiteratureReferences
+    TrackLiteratureReferences.default()
+except:
+    pass
+
+def get_data(path):
+    return os.path.join(_AMUSE_ROOT, 'data', path)
